@@ -2,11 +2,17 @@ import socket
 from importlib import import_module, reload
 from os import walk, path, mkdir
 from os.path import abspath, dirname, exists, join
-from typing import Union, Optional
-
+from typing import Union, Optional, TYPE_CHECKING, Tuple
+import sys
 import grpc_tools.protoc
 import pkg_resources
 from jinja2 import Environment, FileSystemLoader
+from grpcalchemy.config import DefaultConfig
+
+if TYPE_CHECKING:
+    from grpcalchemy.server import Server
+    from grpcalchemy.blueprint import Blueprint
+
 
 try:
     af_unix = socket.AF_UNIX
@@ -15,6 +21,11 @@ except AttributeError:  # pragma: no cover
 
 from .meta import __meta__
 
+if sys.platform == "win32":
+    FILE_SEPARATOR = "\\"
+else:
+    FILE_SEPARATOR = "/"
+
 curdir = "."
 
 
@@ -62,6 +73,7 @@ def generate_proto_file(template_path_root: str = "", template_path: str = "prot
         loader=FileSystemLoader(
             searchpath=abspath(join(dirname(__file__), "templates"))
         ),
+        autoescape=False,
         trim_blocks=True,
         lstrip_blocks=True,
     )
@@ -83,7 +95,7 @@ def generate_proto_file(template_path_root: str = "", template_path: str = "prot
     # copy from grpc_tools
     protoc_file = pkg_resources.resource_filename("grpc_tools", "protoc.py")
     proto_include = pkg_resources.resource_filename("grpc_tools", "_proto")
-    for root, dirs, files in walk(f"./{template_path}/"):
+    for _, dirs, files in walk(f"{template_path}"):
         for file in files:
             if file[-5:] == "proto":
                 grpc_tools.protoc.main(
@@ -92,16 +104,16 @@ def generate_proto_file(template_path_root: str = "", template_path: str = "prot
                         "-I.",
                         "--python_out=.",
                         "--grpc_python_out=.",
-                        f"./{template_path}/{file}",
+                        f".{FILE_SEPARATOR}{template_path}{FILE_SEPARATOR}{file}",
                     ]
                     + ["-I{}".format(proto_include)]
                 )
     for meta in __meta__.values():
-        reload(import_module(abs_template_path.split("/", 1)[0]))
+        reload(import_module(abs_template_path.split(FILE_SEPARATOR, 1)[0]))
         for messageCls in meta.messages:
             # populated exact gRPCMessageClass from pb2 file
             gpr_message_module = import_module(
-                f"{join(abs_template_path, messageCls.__filename__).replace('/', '.')}_pb2"
+                f"{join(abs_template_path, messageCls.__filename__).replace(FILE_SEPARATOR, '.')}_pb2"
             )
             gpr_message_module = reload(gpr_message_module)
             gRPCMessageClass = getattr(
@@ -110,6 +122,24 @@ def generate_proto_file(template_path_root: str = "", template_path: str = "prot
             messageCls.gRPCMessageClass = gRPCMessageClass
 
 
+def add_blueprint_to_server(
+    config: DefaultConfig, bp: "Blueprint", server: "Server"
+) -> Tuple[str, ...]:
+    grpc_pb2_grpc_module = import_module(
+        f"{join(config.PROTO_TEMPLATE_ROOT, config.PROTO_TEMPLATE_PATH, bp.access_file_name()).replace(FILE_SEPARATOR, '.')}_pb2_grpc"
+    )
+    grpc_pb2_module = import_module(
+        f"{join(config.PROTO_TEMPLATE_ROOT, config.PROTO_TEMPLATE_PATH, bp.access_file_name()).replace(FILE_SEPARATOR, '.')}_pb2"
+    )
+    getattr(grpc_pb2_grpc_module, f"add_{bp.access_service_name()}Servicer_to_server")(
+        bp, server
+    )
+    return tuple(
+        service.full_name
+        for service in getattr(grpc_pb2_module, "DESCRIPTOR").services_by_name.values()
+    )
+
+
 def select_address_family(host: str) -> int:
     """Return ``AF_INET4``, ``AF_INET6``, or ``AF_UNIX`` depending on
     the host and port."""
